
// File: index.xml

// File: classAngularReflectometryCoordinates.xml
%feature("docstring") AngularReflectometryCoordinates "

Conversion of axis units for the case of conventional (angle-based) reflectometry.

C++ includes: CoordSystem1D.h
";

%feature("docstring")  AngularReflectometryCoordinates::AngularReflectometryCoordinates "AngularReflectometryCoordinates::AngularReflectometryCoordinates(double wavelength, const IAxis &axis, Coords axis_units=Coords::RADIANS)

Constructs the object for unit conversion. 
";

%feature("docstring")  AngularReflectometryCoordinates::~AngularReflectometryCoordinates "AngularReflectometryCoordinates::~AngularReflectometryCoordinates() override
";

%feature("docstring")  AngularReflectometryCoordinates::clone "AngularReflectometryCoordinates * AngularReflectometryCoordinates::clone() const override
";

%feature("docstring")  AngularReflectometryCoordinates::availableUnits "std::vector< Coords > AngularReflectometryCoordinates::availableUnits() const override

Returns the list of all available units. 
";

%feature("docstring")  AngularReflectometryCoordinates::defaultUnits "Coords AngularReflectometryCoordinates::defaultUnits() const override

Returns default units to convert to. 
";


// File: structAxisInfo.xml
%feature("docstring") AxisInfo "

Information about an axis in specific units. Can be used for plotting.

C++ includes: SimulationResult.h
";


// File: classBeam.xml
%feature("docstring") Beam "

An incident neutron or x-ray beam.

C++ includes: Beam.h
";

%feature("docstring")  Beam::Beam "Beam::Beam(double intensity, double wavelength, const Direction &direction)
";

%feature("docstring")  Beam::Beam "Beam::Beam(const Beam &other)
";

%feature("docstring")  Beam::~Beam "Beam::~Beam() override
";

%feature("docstring")  Beam::clone "Beam * Beam::clone() const
";

%feature("docstring")  Beam::className "std::string Beam::className() const final
";

%feature("docstring")  Beam::nodeChildren "std::vector< const INode * > Beam::nodeChildren() const override
";

%feature("docstring")  Beam::intensity "double Beam::intensity() const

Returns the beam intensity in neutrons/sec. 
";

%feature("docstring")  Beam::wavelength "double Beam::wavelength() const
";

%feature("docstring")  Beam::direction "Direction Beam::direction() const
";

%feature("docstring")  Beam::polVector "R3 Beam::polVector() const

Returns polarization density as Bloch vector. 
";

%feature("docstring")  Beam::polMatrix "SpinMatrix Beam::polMatrix() const

Returns the polarization density matrix (in spin basis along z-axis) 
";

%feature("docstring")  Beam::footprintFactor "const IFootprintFactor * Beam::footprintFactor() const

Returns footprint factor. 
";

%feature("docstring")  Beam::setInclinationAngleGuarded "void Beam::setInclinationAngleGuarded(double value)

Check for limits, set the value if within limits. Throws if limits are violated. 
";

%feature("docstring")  Beam::setAzimuthalAngleGuarded "void Beam::setAzimuthalAngleGuarded(double value)

Check for limits, set the value if within limits. Throws if limits are violated. 
";

%feature("docstring")  Beam::setWavelengthGuarded "void Beam::setWavelengthGuarded(double value)

Check for limits, set the value if within limits. Throws if limits are violated. 
";

%feature("docstring")  Beam::setWavelength "void Beam::setWavelength(double wavelength)
";

%feature("docstring")  Beam::setDirection "void Beam::setDirection(const Direction &direction)
";

%feature("docstring")  Beam::setInclination "void Beam::setInclination(double alpha)
";

%feature("docstring")  Beam::setInclinationLimits "void Beam::setInclinationLimits(const RealLimits &limits)
";

%feature("docstring")  Beam::setIntensity "void Beam::setIntensity(double intensity)

Sets the beam intensity in neutrons/sec. 
";

%feature("docstring")  Beam::setFootprintFactor "void Beam::setFootprintFactor(const IFootprintFactor &shape_factor)

Sets footprint factor to the beam. 
";

%feature("docstring")  Beam::setPolarization "void Beam::setPolarization(R3 bloch_vector)

Sets the polarization density matrix according to the given Bloch vector. 
";


// File: classConvolutionDetectorResolution.xml
%feature("docstring") ConvolutionDetectorResolution "

Limitation: this class assumes that the data points are evenly distributed on each axis.

Convolutes the intensity in 1 or 2 dimensions with a resolution function.

C++ includes: ConvolutionDetectorResolution.h
";

%feature("docstring")  ConvolutionDetectorResolution::ConvolutionDetectorResolution "ConvolutionDetectorResolution::ConvolutionDetectorResolution(cumulative_DF_1d res_function_1d)

Constructor taking a 1 dimensional resolution function as argument. 
";

%feature("docstring")  ConvolutionDetectorResolution::ConvolutionDetectorResolution "ConvolutionDetectorResolution::ConvolutionDetectorResolution(const IResolutionFunction2D &p_res_function_2d)

Constructor taking a 2 dimensional resolution function as argument. 
";

%feature("docstring")  ConvolutionDetectorResolution::~ConvolutionDetectorResolution "ConvolutionDetectorResolution::~ConvolutionDetectorResolution() override
";

%feature("docstring")  ConvolutionDetectorResolution::clone "ConvolutionDetectorResolution * ConvolutionDetectorResolution::clone() const override
";

%feature("docstring")  ConvolutionDetectorResolution::className "std::string ConvolutionDetectorResolution::className() const final
";

%feature("docstring")  ConvolutionDetectorResolution::applyDetectorResolution "void ConvolutionDetectorResolution::applyDetectorResolution(Powerfield< double > *p_intensity_map) const override

Convolve given intensities with the encapsulated resolution. 
";

%feature("docstring")  ConvolutionDetectorResolution::getResolutionFunction2D "const IResolutionFunction2D * ConvolutionDetectorResolution::getResolutionFunction2D() const
";

%feature("docstring")  ConvolutionDetectorResolution::nodeChildren "std::vector< const INode * > ConvolutionDetectorResolution::nodeChildren() const override
";


// File: classConvolve.xml
%feature("docstring") Convolve "

Convolution of two real vectors (in 1D or 2D) using Fast Fourier Transform.

Usage: std::vector<double> signal, kernel, result;  Convolve cv; cv.fftconvolve(signal, kernel, result)

Given code rely on code from Jeremy Fix page, http://jeremy.fix.free.fr/spip.php?article15, see also \"Efficient convolution using the Fast Fourier Transform, Application in C++\" by Jeremy Fix, May 30, 2011

C++ includes: Convolve.h
";

%feature("docstring")  Convolve::Convolve "Convolve::Convolve()
";

%feature("docstring")  Convolve::fftconvolve "void Convolve::fftconvolve(const double1d_t &source, const double1d_t &kernel, double1d_t &result)

convolution in 1D 
";

%feature("docstring")  Convolve::fftconvolve "void Convolve::fftconvolve(const double2d_t &source, const double2d_t &kernel, double2d_t &result)

convolution in 2D 
";

%feature("docstring")  Convolve::init "void Convolve::init(int h_src, int w_src, int h_kernel, int w_kernel)

prepare arrays for 2D convolution of given vectors 
";

%feature("docstring")  Convolve::setMode "void Convolve::setMode(EConvolutionMode mode)

Sets convolution mode. 
";


// File: classCoordSystem1D.xml
%feature("docstring") CoordSystem1D "

Abstract base class to support coordinate transforms and axis labels for 1D scans. Inherited by  AngularReflectometryCoordinates and  WavenumberReflectometryCoordinates.

C++ includes: CoordSystem1D.h
";

%feature("docstring")  CoordSystem1D::CoordSystem1D "CoordSystem1D::CoordSystem1D(const IAxis *&&axis)

Takes ownership of axis. 
";

%feature("docstring")  CoordSystem1D::~CoordSystem1D "CoordSystem1D::~CoordSystem1D() override=default
";

%feature("docstring")  CoordSystem1D::clone "CoordSystem1D* CoordSystem1D::clone() const override=0
";

%feature("docstring")  CoordSystem1D::rank "size_t CoordSystem1D::rank() const override

Returns dimensionality of converted canvas. 
";

%feature("docstring")  CoordSystem1D::axisSize "size_t CoordSystem1D::axisSize(size_t i_axis) const override

Returns the size of underlying axis. 
";

%feature("docstring")  CoordSystem1D::calculateMin "double CoordSystem1D::calculateMin(size_t i_axis, Coords units) const override

Calculates minimum on-axis value in given units. 
";

%feature("docstring")  CoordSystem1D::calculateMax "double CoordSystem1D::calculateMax(size_t i_axis, Coords units) const override

Calculates maximum on-axis value in given units. 
";

%feature("docstring")  CoordSystem1D::createConvertedAxis "IAxis * CoordSystem1D::createConvertedAxis(size_t i_axis, Coords units) const override

Creates axis in converted units. 
";

%feature("docstring")  CoordSystem1D::createConvertedData "Powerfield< double > * CoordSystem1D::createConvertedData(const Powerfield< double > &data, Coords units) const override

Creates  Powerfield array in converter units. 
";


// File: classCoordSystem2D.xml
%feature("docstring") CoordSystem2D "

Interface for objects that provide axis translations to different units for  IDetector objects.

C++ includes: CoordSystem2D.h
";

%feature("docstring")  CoordSystem2D::CoordSystem2D "CoordSystem2D::CoordSystem2D(const Direction &direction, double wavelength=0)
";

%feature("docstring")  CoordSystem2D::CoordSystem2D "CoordSystem2D::CoordSystem2D(const OwningVector< IAxis > &axes, const Direction &direction, double wavelength=0)
";

%feature("docstring")  CoordSystem2D::~CoordSystem2D "CoordSystem2D::~CoordSystem2D() override=default
";

%feature("docstring")  CoordSystem2D::rank "size_t CoordSystem2D::rank() const override
";

%feature("docstring")  CoordSystem2D::calculateMin "double CoordSystem2D::calculateMin(size_t i_axis, Coords units) const override
";

%feature("docstring")  CoordSystem2D::calculateMax "double CoordSystem2D::calculateMax(size_t i_axis, Coords units) const override
";

%feature("docstring")  CoordSystem2D::axisSize "size_t CoordSystem2D::axisSize(size_t i_axis) const override
";

%feature("docstring")  CoordSystem2D::availableUnits "std::vector< Coords > CoordSystem2D::availableUnits() const override

Returns list of units that are available for all 2D detectors. Further units may be added by child classes. 
";

%feature("docstring")  CoordSystem2D::createConvertedAxis "IAxis * CoordSystem2D::createConvertedAxis(size_t i_axis, Coords units) const override
";


// File: classCumulativeValue.xml
%feature("docstring") CumulativeValue "

The cumulative value, with on-the-flight calculation of average and root mean square.

C++ includes: CumulativeValue.h
";

%feature("docstring")  CumulativeValue::CumulativeValue "CumulativeValue::CumulativeValue()
";

%feature("docstring")  CumulativeValue::clear "void CumulativeValue::clear()
";

%feature("docstring")  CumulativeValue::setContent "void CumulativeValue::setContent(double value)
";

%feature("docstring")  CumulativeValue::add "void CumulativeValue::add(double value, double weight=1.0)
";

%feature("docstring")  CumulativeValue::getNumberOfEntries "int CumulativeValue::getNumberOfEntries() const
";

%feature("docstring")  CumulativeValue::getContent "double CumulativeValue::getContent() const
";

%feature("docstring")  CumulativeValue::getAverage "double CumulativeValue::getAverage() const
";

%feature("docstring")  CumulativeValue::getRMS "double CumulativeValue::getRMS() const
";


// File: classDepthProbeCoordinates.xml
%feature("docstring") DepthProbeCoordinates "

DepthProbeCoordinates class handles the unit translations for depth probe simulations Its default units are radians for x-axis and nm for y-axis

C++ includes: CoordSystem2D.h
";

%feature("docstring")  DepthProbeCoordinates::DepthProbeCoordinates "DepthProbeCoordinates::DepthProbeCoordinates(const OwningVector< IAxis > &axes, const Direction &direction, double wavelength)
";

%feature("docstring")  DepthProbeCoordinates::~DepthProbeCoordinates "DepthProbeCoordinates::~DepthProbeCoordinates() override
";

%feature("docstring")  DepthProbeCoordinates::clone "DepthProbeCoordinates * DepthProbeCoordinates::clone() const override
";

%feature("docstring")  DepthProbeCoordinates::availableUnits "std::vector< Coords > DepthProbeCoordinates::availableUnits() const override

Returns list of units that are available for all 2D detectors. Further units may be added by child classes. 
";

%feature("docstring")  DepthProbeCoordinates::defaultUnits "Coords DepthProbeCoordinates::defaultUnits() const override
";


// File: classDetectorContext.xml
%feature("docstring") DetectorContext "

Holds precalculated information for faster DiffuseElement generation.

C++ includes: DetectorContext.h
";

%feature("docstring")  DetectorContext::DetectorContext "DetectorContext::DetectorContext(const IDetector *detector)
";

%feature("docstring")  DetectorContext::DetectorContext "DetectorContext::DetectorContext(const DetectorContext &other)=delete
";

%feature("docstring")  DetectorContext::numberOfElements "size_t DetectorContext::numberOfElements() const
";

%feature("docstring")  DetectorContext::createPixel "std::unique_ptr< IPixel > DetectorContext::createPixel(size_t element_index) const

Creates pixel for given element index. Element index is sequential index in a vector of DiffuseElements. Corresponds to sequence of detector bins inside ROI and outside of masked areas. 
";

%feature("docstring")  DetectorContext::detectorIndex "size_t DetectorContext::detectorIndex(size_t element_index) const
";


// File: classDetectorMask.xml
%feature("docstring") DetectorMask "

Collection of detector masks.

C++ includes: DetectorMask.h
";

%feature("docstring")  DetectorMask::DetectorMask "DetectorMask::DetectorMask(const IAxis &xAxis, const IAxis &yAxis)
";

%feature("docstring")  DetectorMask::~DetectorMask "DetectorMask::~DetectorMask()
";

%feature("docstring")  DetectorMask::DetectorMask "DetectorMask::DetectorMask(const DetectorMask &other)
";

%feature("docstring")  DetectorMask::addMask "void DetectorMask::addMask(const IShape2D &shape, bool mask_value)

Add mask to the stack of detector masks. The value \"true\" means that the area will be excluded from the analysis.

Parameters:
-----------

shape: 
The shape of mask.

mask_value: 
The value of mask 
";

%feature("docstring")  DetectorMask::initMaskData "void DetectorMask::initMaskData(const IAxis &xAxis, const IAxis &yAxis)

Init the map of masks for the given detector plane. 
";

%feature("docstring")  DetectorMask::isMasked "bool DetectorMask::isMasked(size_t index) const
";

%feature("docstring")  DetectorMask::getMaskData "const Powerfield<bool>* DetectorMask::getMaskData() const
";

%feature("docstring")  DetectorMask::hasMasks "bool DetectorMask::hasMasks() const

Returns true if has masks. 
";

%feature("docstring")  DetectorMask::numberOfMaskedChannels "int DetectorMask::numberOfMaskedChannels() const
";

%feature("docstring")  DetectorMask::numberOfMasks "size_t DetectorMask::numberOfMasks() const
";

%feature("docstring")  DetectorMask::patternAt "const MaskPattern * DetectorMask::patternAt(size_t iMask) const
";


// File: classEllipse.xml
%feature("docstring") Ellipse "

An ellipse, for use in detector masks.

C++ includes: Ellipse.h
";

%feature("docstring")  Ellipse::Ellipse "Ellipse::Ellipse(double xcenter, double ycenter, double xradius, double yradius, double theta=0.0)

Parameters:
-----------

xcenter: 
x-coordinate of  Ellipse's center

ycenter: 
y-coordinate of  Ellipse's center

xradius: 
Radius along x-axis

yradius: 
Radius along y-axis

theta: 
Angle of  Ellipse rotation in radians 
";

%feature("docstring")  Ellipse::clone "Ellipse* Ellipse::clone() const override
";

%feature("docstring")  Ellipse::contains "bool Ellipse::contains(double x, double y) const override

Returns true if point with given coordinates is inside or on border of the shape. 
";

%feature("docstring")  Ellipse::contains "bool Ellipse::contains(const Bin1D &binx, const Bin1D &biny) const override

Returns true if area defined by two bins is inside or on border of ellipse; more precisely, if mid point of two bins satisfy this condition. 
";

%feature("docstring")  Ellipse::getCenterX "double Ellipse::getCenterX() const
";

%feature("docstring")  Ellipse::getCenterY "double Ellipse::getCenterY() const
";

%feature("docstring")  Ellipse::radiusX "double Ellipse::radiusX() const
";

%feature("docstring")  Ellipse::radiusY "double Ellipse::radiusY() const
";

%feature("docstring")  Ellipse::getTheta "double Ellipse::getTheta() const
";


// File: classFootprintGauss.xml
%feature("docstring") FootprintGauss "

Gaussian beam footprint.

Beam width is the full width at half maximum.

C++ includes: FootprintGauss.h
";

%feature("docstring")  FootprintGauss::FootprintGauss "FootprintGauss::FootprintGauss(std::vector< double > P)
";

%feature("docstring")  FootprintGauss::FootprintGauss "FootprintGauss::FootprintGauss(double width_ratio)
";

%feature("docstring")  FootprintGauss::clone "FootprintGauss * FootprintGauss::clone() const override
";

%feature("docstring")  FootprintGauss::className "std::string FootprintGauss::className() const final
";

%feature("docstring")  FootprintGauss::parDefs "std::vector<ParaMeta> FootprintGauss::parDefs() const final
";

%feature("docstring")  FootprintGauss::calculate "double FootprintGauss::calculate(double alpha) const override

Calculate footprint correction coefficient from the beam incident angle  alpha. 
";

%feature("docstring")  FootprintGauss::name "std::string FootprintGauss::name() const override
";


// File: classFootprintSquare.xml
%feature("docstring") FootprintSquare "

Rectangular beam footprint.

C++ includes: FootprintSquare.h
";

%feature("docstring")  FootprintSquare::FootprintSquare "FootprintSquare::FootprintSquare(std::vector< double > P)
";

%feature("docstring")  FootprintSquare::FootprintSquare "FootprintSquare::FootprintSquare(double width_ratio)
";

%feature("docstring")  FootprintSquare::clone "FootprintSquare * FootprintSquare::clone() const override
";

%feature("docstring")  FootprintSquare::className "std::string FootprintSquare::className() const final
";

%feature("docstring")  FootprintSquare::parDefs "std::vector<ParaMeta> FootprintSquare::parDefs() const final
";

%feature("docstring")  FootprintSquare::calculate "double FootprintSquare::calculate(double alpha) const override

Calculate footprint correction coefficient from the beam incident angle  alpha. 
";

%feature("docstring")  FootprintSquare::name "std::string FootprintSquare::name() const override
";


// File: classHistogram1D.xml
%feature("docstring") Histogram1D "

One dimensional histogram.

C++ includes: Histogram1D.h
";

%feature("docstring")  Histogram1D::Histogram1D "Histogram1D::Histogram1D(int nbinsx, double xlow, double xup)

Constructor for fix bin size histograms.

Parameters:
-----------

nbinsx: 
number of bins

xlow: 
low edge of the first bin

xup: 
upper edge of the last bin 
";

%feature("docstring")  Histogram1D::Histogram1D "Histogram1D::Histogram1D(int nbinsx, const std::vector< double > &xbins)

Constructor for variable bin size histograms.

Parameters:
-----------

nbinsx: 
number of bins

xbins: 
Array of size nbins+1 containing low-edges for each bin and upper edge of last bin. 
";

%feature("docstring")  Histogram1D::Histogram1D "Histogram1D::Histogram1D(const IAxis &axis)

Constructor for 1D histogram with custom axis. 
";

%feature("docstring")  Histogram1D::Histogram1D "Histogram1D::Histogram1D(const Powerfield< double > &data)

Constructor for 1D histograms from basic  Powerfield object. 
";

%feature("docstring")  Histogram1D::clone "Histogram1D * Histogram1D::clone() const override

Returns clone of other histogram. 
";

%feature("docstring")  Histogram1D::rank "size_t Histogram1D::rank() const override

Returns the number of histogram dimensions. 
";

%feature("docstring")  Histogram1D::fill "int Histogram1D::fill(double x, double weight=1.0)

Increment bin with abscissa x with a weight. 
";

%feature("docstring")  Histogram1D::binCenters "std::vector< double > Histogram1D::binCenters() const

Returns vector of histogram bin centers. 
";

%feature("docstring")  Histogram1D::binValues "std::vector< double > Histogram1D::binValues() const

Returns vector of bin content (the value accumulated by bins) 
";

%feature("docstring")  Histogram1D::binErrors "std::vector< double > Histogram1D::binErrors() const

Returns vector of bin errors. 
";

%feature("docstring")  Histogram1D::binCentersNumpy "PyObject * Histogram1D::binCentersNumpy() const
";

%feature("docstring")  Histogram1D::binValuesNumpy "PyObject * Histogram1D::binValuesNumpy() const
";

%feature("docstring")  Histogram1D::binErrorsNumpy "PyObject * Histogram1D::binErrorsNumpy() const
";

%feature("docstring")  Histogram1D::crop "Histogram1D * Histogram1D::crop(double xmin, double xmax)

Creates new histogram by applying crop on axis. 
";


// File: classHistogram2D.xml
%feature("docstring") Histogram2D "

Two dimensional histogram.

C++ includes: Histogram2D.h
";

%feature("docstring")  Histogram2D::Histogram2D "Histogram2D::Histogram2D(int nbinsx, double xlow, double xup, int nbinsy, double ylow, double yup)

Constructor for fix bin size histograms.

Parameters:
-----------

nbinsx: 
number of bins on X-axis

xlow: 
low edge of the first bin of X-axis

xup: 
upper edge of the last bin of X-axis

nbinsy: 
number of bins on Y axis

ylow: 
low edge of the first bin of Y-axis

yup: 
upper edge of the last bin of Y-axis 
";

%feature("docstring")  Histogram2D::Histogram2D "Histogram2D::Histogram2D(int nbinsx, const std::vector< double > &xbins, int nbinsy, const std::vector< double > &ybins)

Constructor for variable bin size histograms.

Parameters:
-----------

nbinsx: 
number of bins on X-axis

xbins: 
Array of size nbins+1 containing low-edges for each bin and upper edge of last bin.

nbinsy: 
number of bins on Y-axis

ybins: 
Array of size nbins+1 containing low-edges for each bin and upper edge of last bin. 
";

%feature("docstring")  Histogram2D::Histogram2D "Histogram2D::Histogram2D(const IAxis &axis_x, const IAxis &axis_y)

Constructor for 2D histogram with custom axes. 
";

%feature("docstring")  Histogram2D::Histogram2D "Histogram2D::Histogram2D(const Powerfield< double > &data)

Constructor for 2D histograms from basic  Powerfield object. 
";

%feature("docstring")  Histogram2D::clone "Histogram2D * Histogram2D::clone() const override

Constructor for 2D histograms from numpy array (thanks to swig)

Returns clone of other histogram 
";

%feature("docstring")  Histogram2D::rank "size_t Histogram2D::rank() const override

Returns the number of histogram dimensions. 
";

%feature("docstring")  Histogram2D::fill "int Histogram2D::fill(double x, double y, double weight=1.0)

Increment bin with abscissa x and ordinate y with a weight. 
";

%feature("docstring")  Histogram2D::projectionX "Histogram1D * Histogram2D::projectionX()

Project a 2D histogram into 1D histogram along X. The projection is made from all bins along y-axis. 
";

%feature("docstring")  Histogram2D::projectionX "Histogram1D * Histogram2D::projectionX(double yvalue)

Project a 2D histogram into 1D histogram along X. The projection is made from the y-bin closest to given ordinate yvalue.

Parameters:
-----------

yvalue: 
the value on y-axis at which projection is taken 
";

%feature("docstring")  Histogram2D::projectionX "Histogram1D * Histogram2D::projectionX(double ylow, double yup)

Project a 2D histogram into 1D histogram along X. The projection is made from all y-bins corresponding to ordinate between ylow and yup.

Parameters:
-----------

ylow: 
lower edje on y-axis

yup: 
upper edje on y-axis 
";

%feature("docstring")  Histogram2D::projectionY "Histogram1D * Histogram2D::projectionY()

Project a 2D histogram into 1D histogram along Y. The projection is made from all bins along x-axis. 
";

%feature("docstring")  Histogram2D::projectionY "Histogram1D * Histogram2D::projectionY(double xvalue)

Project a 2D histogram into 1D histogram along Y. The projection is made from the x-bin closest to given abscissa xvalue.

Parameters:
-----------

xvalue: 
the value on x-axis at which projection is taken 
";

%feature("docstring")  Histogram2D::projectionY "Histogram1D * Histogram2D::projectionY(double xlow, double xup)

Project a 2D histogram into 1D histogram along Y. The projection is made from all x-bins corresponding to abscissa between xlow and xup.

Parameters:
-----------

xlow: 
lower edje on x-axis

xup: 
upper edje on x-axis 
";

%feature("docstring")  Histogram2D::crop "Histogram2D * Histogram2D::crop(double xmin, double ymin, double xmax, double ymax)

Creates new histogram by applying rectangular clip. 
";

%feature("docstring")  Histogram2D::setContent "void Histogram2D::setContent(const std::vector< std::vector< double >> &data)

Sets the values in histograms channels from numpy array,. 
";

%feature("docstring")  Histogram2D::addContent "void Histogram2D::addContent(const std::vector< std::vector< double >> &data)

Add to values in histograms channels from numpy array,. 
";


// File: classHorizontalLine.xml
%feature("docstring") HorizontalLine "

An infinite horizontal line.

C++ includes: Line.h
";

%feature("docstring")  HorizontalLine::HorizontalLine "HorizontalLine::HorizontalLine(double y)

Parameters:
-----------

y: 
The value at which it crosses y-axes 
";

%feature("docstring")  HorizontalLine::clone "HorizontalLine* HorizontalLine::clone() const override
";

%feature("docstring")  HorizontalLine::contains "bool HorizontalLine::contains(double x, double y) const override

Returns true if point with given coordinates is inside or on border of the shape. 
";

%feature("docstring")  HorizontalLine::contains "bool HorizontalLine::contains(const Bin1D &binx, const Bin1D &biny) const override

Returns true if area defined by two bins is inside or on border of polygon (more precisely, if mid point of two bins satisfy this condition). 
";

%feature("docstring")  HorizontalLine::getYpos "double HorizontalLine::getYpos() const
";


// File: classICoordSystem.xml
%feature("docstring") ICoordSystem "

Interface to provide axis translations to different units for simulation output.

Child classes are currently declared in
Device/Detector/CoordSystem2D.h,

Core/Scan/CoordSystem1D.h.

C++ includes: ICoordSystem.h
";

%feature("docstring")  ICoordSystem::~ICoordSystem "ICoordSystem::~ICoordSystem() override
";

%feature("docstring")  ICoordSystem::clone "ICoordSystem* ICoordSystem::clone() const override=0
";

%feature("docstring")  ICoordSystem::rank "virtual size_t ICoordSystem::rank() const =0
";

%feature("docstring")  ICoordSystem::calculateMin "virtual double ICoordSystem::calculateMin(size_t i_axis, Coords units) const =0
";

%feature("docstring")  ICoordSystem::calculateMax "virtual double ICoordSystem::calculateMax(size_t i_axis, Coords units) const =0
";

%feature("docstring")  ICoordSystem::axisSize "virtual size_t ICoordSystem::axisSize(size_t i_axis) const =0
";

%feature("docstring")  ICoordSystem::axisName "std::string ICoordSystem::axisName(size_t i_axis, Coords units=Coords::UNDEFINED) const
";

%feature("docstring")  ICoordSystem::availableUnits "virtual std::vector<Coords> ICoordSystem::availableUnits() const =0
";

%feature("docstring")  ICoordSystem::defaultUnits "virtual Coords ICoordSystem::defaultUnits() const =0
";

%feature("docstring")  ICoordSystem::createConvertedAxis "virtual IAxis* ICoordSystem::createConvertedAxis(size_t i_axis, Coords units) const =0
";

%feature("docstring")  ICoordSystem::defaultAxes "std::vector< IAxis * > ICoordSystem::defaultAxes() const
";

%feature("docstring")  ICoordSystem::convertedAxes "std::vector< IAxis * > ICoordSystem::convertedAxes(Coords units) const
";

%feature("docstring")  ICoordSystem::createConvertedData "Powerfield< double > * ICoordSystem::createConvertedData(const Powerfield< double > &data, Coords units) const

Creates  Powerfield array in converter units. 
";


// File: classIDetector.xml
%feature("docstring") IDetector "

Abstract detector interface.

Handles also \"region of interest\" (ROI). In general, the ROI is the whole detector, and all methods related to ROI work on the whole detector. If a ROI different to the detector size is explicitly set, then ROI-related methods work on this reduced ROI. Therefore, when calling ROI related methods, the distinction between \"explicit
ROI exists: yes/no\" does not have to be made by the caller, but it is handled in here. For access to the whole detector, even if a smaller ROI is explicitly defined, use the non-ROI-related methods like  totalSize() or axes(). Any method which is not speaking of \"explicit ROI\" handles the \"implicit ROI\", i.e. uses an explicitly set ROI or the whole detector if no explicit ROI exists. To access the explicitly set ROI, use the methods which have the explicit in its name, like  sizeOfExplicitRegionOfInterest().

C++ includes: IDetector.h
";

%feature("docstring")  IDetector::IDetector "IDetector::IDetector()
";

%feature("docstring")  IDetector::clone "IDetector* IDetector::clone() const override=0
";

%feature("docstring")  IDetector::~IDetector "IDetector::~IDetector() override
";

%feature("docstring")  IDetector::setDetectorNormal "virtual void IDetector::setDetectorNormal(const Direction &)

Inits detector with the beam settings. 
";

%feature("docstring")  IDetector::addDetAxis "void IDetector::addDetAxis(const IAxis &axis)
";

%feature("docstring")  IDetector::setAnalyzer "void IDetector::setAnalyzer(R3 direction, double efficiency, double total_transmission)

Sets the polarization analyzer characteristics of the detector. 
";

%feature("docstring")  IDetector::setDetectorResolution "void IDetector::setDetectorResolution(const IDetectorResolution &p_detector_resolution)

Sets the detector resolution. 
";

%feature("docstring")  IDetector::setResolutionFunction "void IDetector::setResolutionFunction(const IResolutionFunction2D &resFunc)
";

%feature("docstring")  IDetector::resetRegionOfInterest "void IDetector::resetRegionOfInterest()

Resets region of interest making whole detector plane available for the simulation. 
";

%feature("docstring")  IDetector::nodeChildren "std::vector< const INode * > IDetector::nodeChildren() const override
";

%feature("docstring")  IDetector::iterateOverRegionOfInterest "void IDetector::iterateOverRegionOfInterest(std::function< void(const_iterator)> func) const

Iterate over all points within \"region of interest\", no matter whether they are masked or not. If no region of interest is explicitly defined, then the whole detector is taken as \"region of interest\". 
";

%feature("docstring")  IDetector::iterateOverNonMaskedPoints "void IDetector::iterateOverNonMaskedPoints(std::function< void(const_iterator)> func) const

Iterate over all non-masked points within \"region of interest\". If no region of interest is explicitly defined, then the whole detector is taken as \"region of interest\". 
";

%feature("docstring")  IDetector::setDetectorParameters "void IDetector::setDetectorParameters(size_t n_x, double x_min, double x_max, size_t n_y, double y_min, double y_max)

Sets equidistant axes. 
";

%feature("docstring")  IDetector::detectorMask "const DetectorMask * IDetector::detectorMask() const
";

%feature("docstring")  IDetector::addMask "void IDetector::addMask(const IShape2D &shape, bool mask_value=true)

Adds mask of given shape to the stack of detector masks. The mask value 'true' means that the channel will be excluded from the simulation. The mask which is added last has priority.

Parameters:
-----------

shape: 
The shape of mask ( Rectangle,  Polygon,  Line,  Ellipse)

mask_value: 
The value of mask 
";

%feature("docstring")  IDetector::maskAll "void IDetector::maskAll()

Put the mask for all detector channels (i.e. exclude whole detector from the analysis) 
";

%feature("docstring")  IDetector::setRegionOfInterest "void IDetector::setRegionOfInterest(double xlow, double ylow, double xup, double yup)

Sets rectangular region of interest with lower left and upper right corners defined. 
";

%feature("docstring")  IDetector::offspecCoords "virtual ICoordSystem* IDetector::offspecCoords(IAxis *beamAxis, const Direction &beamDirection) const =0
";

%feature("docstring")  IDetector::scatteringCoords "virtual CoordSystem2D* IDetector::scatteringCoords(const Beam &beam) const =0
";

%feature("docstring")  IDetector::active_indices "std::vector< size_t > IDetector::active_indices() const

Returns vector of unmasked detector indices. 
";

%feature("docstring")  IDetector::createPixel "virtual IPixel* IDetector::createPixel(size_t index) const =0

Creates an IPixel for the given  Powerfield object and index. 
";

%feature("docstring")  IDetector::indexOfSpecular "virtual size_t IDetector::indexOfSpecular(const Beam &beam) const =0

Returns index of pixel that contains the specular wavevector. If no pixel contains this specular wavevector, the number of pixels is returned. This corresponds to an overflow index. 
";

%feature("docstring")  IDetector::axis "const IAxis & IDetector::axis(size_t index) const

One axis of the complete detector. Any region of interest is not taken into account. 
";

%feature("docstring")  IDetector::rank "size_t IDetector::rank() const

Returns number of defined axes. 
";

%feature("docstring")  IDetector::axisBinIndex "size_t IDetector::axisBinIndex(size_t index, size_t selected_axis) const

Calculate axis index for given global index. 
";

%feature("docstring")  IDetector::totalSize "size_t IDetector::totalSize() const

Returns total number of pixels. Any region of interest is not taken into account. 
";

%feature("docstring")  IDetector::sizeOfRegionOfInterest "size_t IDetector::sizeOfRegionOfInterest() const

The size of the \"Region of Interest\". Same as  totalSize() if no region of interest has been explicitly set. 
";

%feature("docstring")  IDetector::hasExplicitRegionOfInterest "bool IDetector::hasExplicitRegionOfInterest() const

True if a region of interest is explicitly set. 
";

%feature("docstring")  IDetector::axesClippedToRegionOfInterest "OwningVector< IAxis > IDetector::axesClippedToRegionOfInterest() const

Returns the axes clipped to the region of interest. If no region of interest is explicitly defined, then the whole detector is taken as \"region of interest\". 
";

%feature("docstring")  IDetector::regionOfInterestIndexToDetectorIndex "size_t IDetector::regionOfInterestIndexToDetectorIndex(size_t regionOfInterestIndex) const

Convert an index of the region of interest to an index of the detector. If no region of interest is set, then the index stays unmodified (since ROI == detector area). 
";

%feature("docstring")  IDetector::detectorIndexToRegionOfInterestIndex "size_t IDetector::detectorIndexToRegionOfInterestIndex(size_t detectorIndex) const
";

%feature("docstring")  IDetector::applyDetectorResolution "void IDetector::applyDetectorResolution(Powerfield< double > *p_intensity_map) const

Applies the detector resolution to the given intensity maps. 
";

%feature("docstring")  IDetector::detectorResolution "const IDetectorResolution * IDetector::detectorResolution() const

Returns a pointer to detector resolution object. 
";

%feature("docstring")  IDetector::createDetectorIntensity "Powerfield< double > * IDetector::createDetectorIntensity(const std::vector< std::unique_ptr< DiffuseElement >> &elements) const

Returns new intensity map with resolution applied, and cropped to ROI if applicable. 
";

%feature("docstring")  IDetector::defaultCoords "virtual Coords IDetector::defaultCoords() const =0

Return default axes units. 
";

%feature("docstring")  IDetector::numberOfElements "size_t IDetector::numberOfElements() const

Returns number of simulation elements. 
";

%feature("docstring")  IDetector::regionOfInterestBounds "std::pair< double, double > IDetector::regionOfInterestBounds(size_t iAxis) const

The lower and upper bound of the region of interest. If no region of interest is explicitly defined, then the whole detector is taken as \"region of interest\". 
";

%feature("docstring")  IDetector::createContext "std::unique_ptr< DetectorContext > IDetector::createContext() const
";

%feature("docstring")  IDetector::beginNonMaskedPoints "SimulationAreaIterator IDetector::beginNonMaskedPoints() const

Create begin-iterator to iterate over all points which are not masked and lay within the \"Region of Interest\" 
";

%feature("docstring")  IDetector::endNonMaskedPoints "SimulationAreaIterator IDetector::endNonMaskedPoints() const

Create end-iterator to iterate over all points which are not masked and lay within the \"Region of Interest\" 
";

%feature("docstring")  IDetector::beginRegionOfInterestPoints "SimulationAreaIterator IDetector::beginRegionOfInterestPoints() const

Create begin-iterator to iterate over all points which lay within the \"Region of Interest\". If no region of interest is explicitly defined, then the whole detector is taken as \"region of interest\". No matter whether masked or not. 
";

%feature("docstring")  IDetector::endRegionOfInterestPoints "SimulationAreaIterator IDetector::endRegionOfInterestPoints() const

Create end-iterator to iterate over all points which lay within the \"Region of Interest\". If no region of interest is explicitly defined, then the whole detector is taken as \"region of interest\". No matter whether masked or not. 
";

%feature("docstring")  IDetector::createDetectorMap "std::unique_ptr< Powerfield< double > > IDetector::createDetectorMap() const

Returns empty detector map in given axes units. This map is a data array limited to the size of the \"Region of interest\" 
";

%feature("docstring")  IDetector::analyzer "const PolFilter& IDetector::analyzer() const

Returns detection properties. 
";


// File: classIDetectorResolution.xml
%feature("docstring") IDetectorResolution "

Interface for detector resolution algorithms.

C++ includes: IDetectorResolution.h
";

%feature("docstring")  IDetectorResolution::~IDetectorResolution "IDetectorResolution::~IDetectorResolution() override=default
";

%feature("docstring")  IDetectorResolution::clone "IDetectorResolution* IDetectorResolution::clone() const override=0
";

%feature("docstring")  IDetectorResolution::applyDetectorResolution "virtual void IDetectorResolution::applyDetectorResolution(Powerfield< double > *p_intensity_map) const =0

Apply the resolution function to the intensity data. 
";


// File: classIFootprintFactor.xml
%feature("docstring") IFootprintFactor "

Abstract base for classes that calculate the beam footprint factor

C++ includes: IFootprintFactor.h
";

%feature("docstring")  IFootprintFactor::IFootprintFactor "IFootprintFactor::IFootprintFactor(const std::vector< double > &PValues)
";

%feature("docstring")  IFootprintFactor::~IFootprintFactor "IFootprintFactor::~IFootprintFactor() override
";

%feature("docstring")  IFootprintFactor::clone "IFootprintFactor* IFootprintFactor::clone() const override=0
";

%feature("docstring")  IFootprintFactor::widthRatio "double IFootprintFactor::widthRatio() const
";

%feature("docstring")  IFootprintFactor::calculate "virtual double IFootprintFactor::calculate(double alpha) const =0

Calculate footprint correction coefficient from the beam incident angle  alpha. 
";

%feature("docstring")  IFootprintFactor::name "virtual std::string IFootprintFactor::name() const =0
";


// File: classIHistogram.xml
%feature("docstring") IHistogram "

Base class for 1D and 2D histograms holding values of double type.

C++ includes: IHistogram.h
";

%feature("docstring")  IHistogram::IHistogram "IHistogram::IHistogram()
";

%feature("docstring")  IHistogram::IHistogram "IHistogram::IHistogram(const IHistogram &other)
";

%feature("docstring")  IHistogram::~IHistogram "virtual IHistogram::~IHistogram()=default
";

%feature("docstring")  IHistogram::IHistogram "IHistogram::IHistogram(const IAxis &axis_x)
";

%feature("docstring")  IHistogram::IHistogram "IHistogram::IHistogram(const IAxis &axis_x, const IAxis &axis_y)
";

%feature("docstring")  IHistogram::clone "virtual IHistogram* IHistogram::clone() const =0
";

%feature("docstring")  IHistogram::rank "virtual size_t IHistogram::rank() const =0

Returns number of histogram dimensions. 
";

%feature("docstring")  IHistogram::getTotalNumberOfBins "size_t IHistogram::getTotalNumberOfBins() const

Returns total number of histogram bins. For 2D histograms the result will be the product of bin numbers along X and Y axes. 
";

%feature("docstring")  IHistogram::xAxis "const IAxis & IHistogram::xAxis() const

Returns x-axis. 
";

%feature("docstring")  IHistogram::yAxis "const IAxis & IHistogram::yAxis() const

Returns y-axis for 2D histograms. 
";

%feature("docstring")  IHistogram::xMin "double IHistogram::xMin() const

Returns x-axis min (lower edge of first bin). 
";

%feature("docstring")  IHistogram::xMax "double IHistogram::xMax() const

Returns x-axis max (upper edge of last bin). 
";

%feature("docstring")  IHistogram::getNbinsX "size_t IHistogram::getNbinsX() const

Returns number of bins on x-axis. 
";

%feature("docstring")  IHistogram::yMin "double IHistogram::yMin() const

Returns y-axis min (lower edge of first bin) for 2D histograms. 
";

%feature("docstring")  IHistogram::yMax "double IHistogram::yMax() const

Returns y-axis max (upper edge of last bin) for 2D histograms. 
";

%feature("docstring")  IHistogram::getNbinsY "size_t IHistogram::getNbinsY() const

Returns number of bins on y-axis. 
";

%feature("docstring")  IHistogram::getGlobalBin "size_t IHistogram::getGlobalBin(size_t binx, size_t biny=0) const

Returns global bin index for given axes indices. For 1D, just returns binx. 
";

%feature("docstring")  IHistogram::findGlobalBin "size_t IHistogram::findGlobalBin(double x, double y) const

Returns closest global bin index for given axes coordinates. 
";

%feature("docstring")  IHistogram::xAxisIndex "size_t IHistogram::xAxisIndex(size_t i) const

Returns x-axis index for global bin index i. 
";

%feature("docstring")  IHistogram::yAxisIndex "size_t IHistogram::yAxisIndex(size_t i) const

Returns y-axis index for global bin index i. 
";

%feature("docstring")  IHistogram::xAxisValue "double IHistogram::xAxisValue(size_t i)

Returns the center of bin i of the x axis. 
";

%feature("docstring")  IHistogram::yAxisValue "double IHistogram::yAxisValue(size_t i)

Returns the center of bin i of the y axis. 
";

%feature("docstring")  IHistogram::getData "const Powerfield< CumulativeValue > & IHistogram::getData() const
";

%feature("docstring")  IHistogram::getData "Powerfield< CumulativeValue > & IHistogram::getData()
";

%feature("docstring")  IHistogram::binContent "double IHistogram::binContent(size_t i) const

Returns content (accumulated value) of bin i. 
";

%feature("docstring")  IHistogram::binContent "double IHistogram::binContent(size_t binx, size_t biny) const

Returns content (accumulated value) of the 2D histogram bin. 
";

%feature("docstring")  IHistogram::setBinContent "void IHistogram::setBinContent(size_t i, double value)

Sets content of the bin corresponding to the globalbin number. 
";

%feature("docstring")  IHistogram::addBinContent "void IHistogram::addBinContent(size_t i, double value)

Add the value to the bin. 
";

%feature("docstring")  IHistogram::binError "double IHistogram::binError(size_t i) const

Returns error of the bin with given index. 
";

%feature("docstring")  IHistogram::binError "double IHistogram::binError(size_t binx, size_t biny) const

Returns error of the bin with given indices (for 2D histograms). 
";

%feature("docstring")  IHistogram::binAverage "double IHistogram::binAverage(size_t i) const

Returns average value in the bin with given index. 
";

%feature("docstring")  IHistogram::binAverage "double IHistogram::binAverage(size_t binx, size_t biny) const

Returns average value of the bin with given indices (for 2D histograms). 
";

%feature("docstring")  IHistogram::binNumberOfEntries "int IHistogram::binNumberOfEntries(size_t i) const

Returns number of entries in the bin with given index. 
";

%feature("docstring")  IHistogram::binNumberOfEntries "int IHistogram::binNumberOfEntries(size_t binx, size_t biny) const

Returns number of entries in the bin with given indices (for 2D histograms). 
";

%feature("docstring")  IHistogram::getMaximum "double IHistogram::getMaximum() const

Returns histogram maximum value (maximum of  binContent() over all bins) 
";

%feature("docstring")  IHistogram::getMaximumBinIndex "size_t IHistogram::getMaximumBinIndex() const

Returns globalbin index with maximum content. 
";

%feature("docstring")  IHistogram::getMinimum "double IHistogram::getMinimum() const

Returns histogram minimum value (minimum of  binContent() over all bins) 
";

%feature("docstring")  IHistogram::getMinimumBinIndex "size_t IHistogram::getMinimumBinIndex() const

Returns globalbin index with minimum content. 
";

%feature("docstring")  IHistogram::scale "void IHistogram::scale(double value)

Multiply this histogram (every bin content value) by a constant. 
";

%feature("docstring")  IHistogram::integral "double IHistogram::integral() const

Returns integral of bins content (computed as a sum of all bin content). 
";

%feature("docstring")  IHistogram::array "PyObject * IHistogram::array(DataType dataType=DataType::INTEGRAL) const

Returns numpy array with bin content (accumulated values). 
";

%feature("docstring")  IHistogram::reset "void IHistogram::reset()

Reset histogram content (axes remains) 
";

%feature("docstring")  IHistogram::createPowerfield "Powerfield< double > * IHistogram::createPowerfield(DataType dataType=DataType::INTEGRAL) const

Creates new  Powerfield with histogram's shape and values corresponding to DataType.

creates new  Powerfield with histogram's shape and put there values corresponding to DataType 
";

%feature("docstring")  IHistogram::hasSameShape "bool IHistogram::hasSameShape(const IHistogram &other) const

Returns true if objects a) have same dimensions b) bin boundaries of axes coincide. 
";

%feature("docstring")  IHistogram::hasSameSizes "bool IHistogram::hasSameSizes(const IHistogram &other) const

Returns true if object have same rank and number of axes bins. 
";

%feature("docstring")  IHistogram::relativeDifferenceHistogram "IHistogram * IHistogram::relativeDifferenceHistogram(const IHistogram &rhs) const

Returns histogram representing relative difference of two histograms. 
";

%feature("docstring")  IHistogram::save "void IHistogram::save(const std::string &filename) const

Saves histogram in file. Available formats: *.txt, *.tif, *.int (*.txt.gz, *.tif.gz, *.int.gz). 
";

%feature("docstring")  IHistogram::load "void IHistogram::load(const std::string &filename)

Loads histogram from file, the shape of array in file should match. Available formats: *.txt, *.tif, *.int (*.txt.gz, *.tif.gz, *.int.gz). Only bin content will be loaded, histogram axes remain the same. 
";


// File: classImageCoords.xml
%feature("docstring") ImageCoords "

ICoordSystem class that handles the unit translations for rectangular detectors Its default units are mm for both axes

C++ includes: CoordSystem2D.h
";

%feature("docstring")  ImageCoords::ImageCoords "ImageCoords::ImageCoords(const OwningVector< IAxis > &axes, RectangularPixel *regionOfInterestPixel, const Direction &direction, double wavelength)
";

%feature("docstring")  ImageCoords::~ImageCoords "ImageCoords::~ImageCoords() override
";

%feature("docstring")  ImageCoords::clone "ImageCoords * ImageCoords::clone() const override
";

%feature("docstring")  ImageCoords::availableUnits "std::vector< Coords > ImageCoords::availableUnits() const override

Returns list of units that are available for all 2D detectors. Further units may be added by child classes. 
";

%feature("docstring")  ImageCoords::defaultUnits "Coords ImageCoords::defaultUnits() const override
";


// File: classInfinitePlane.xml
%feature("docstring") InfinitePlane "

The infinite plane is used for masking the entire detector.

C++ includes: InfinitePlane.h
";

%feature("docstring")  InfinitePlane::InfinitePlane "InfinitePlane::InfinitePlane()
";

%feature("docstring")  InfinitePlane::clone "InfinitePlane* InfinitePlane::clone() const override
";

%feature("docstring")  InfinitePlane::contains "bool InfinitePlane::contains(double, double) const override

Returns true if point with given coordinates is inside or on border of the shape. 
";

%feature("docstring")  InfinitePlane::contains "bool InfinitePlane::contains(const Bin1D &, const Bin1D &) const override

Returns true if area defined by two bins is inside or on border of polygon (more precisely, if mid point of two bins satisfy this condition). 
";


// File: classIOFactory.xml
%feature("docstring") IOFactory "

Provides users with possibility to read and write IntensityData from/to files in different format. Type of the file will be deduced from file name. *.txt - ASCII file with 2D array [nrow][ncol], layout as in numpy. *.int - BornAgain internal ASCII format. *.tif - 32-bits tiff file. If file name ends with \"*.gz\" or \"*.bz2\" the file will be zipped on the fly using appropriate algorithm.

Usage:

C++ includes: IOFactory.h
";


// File: classIResolutionFunction2D.xml
%feature("docstring") IResolutionFunction2D "

Interface providing two-dimensional resolution function.

C++ includes: IResolutionFunction2D.h
";

%feature("docstring")  IResolutionFunction2D::IResolutionFunction2D "IResolutionFunction2D::IResolutionFunction2D()=default
";

%feature("docstring")  IResolutionFunction2D::IResolutionFunction2D "IResolutionFunction2D::IResolutionFunction2D(const std::vector< double > &PValues)
";

%feature("docstring")  IResolutionFunction2D::~IResolutionFunction2D "IResolutionFunction2D::~IResolutionFunction2D() override=default
";

%feature("docstring")  IResolutionFunction2D::evaluateCDF "virtual double IResolutionFunction2D::evaluateCDF(double x, double y) const =0
";

%feature("docstring")  IResolutionFunction2D::clone "IResolutionFunction2D* IResolutionFunction2D::clone() const override=0
";


// File: classIShape2D.xml
%feature("docstring") IShape2D "

Basic class for all shapes in 2D.

C++ includes: IShape2D.h
";

%feature("docstring")  IShape2D::IShape2D "IShape2D::IShape2D(const char *name)
";

%feature("docstring")  IShape2D::~IShape2D "IShape2D::~IShape2D() override=default
";

%feature("docstring")  IShape2D::clone "IShape2D* IShape2D::clone() const override=0
";

%feature("docstring")  IShape2D::contains "virtual bool IShape2D::contains(double x, double y) const =0

Returns true if point with given coordinates is inside or on border of the shape. 
";

%feature("docstring")  IShape2D::contains "virtual bool IShape2D::contains(const Bin1D &binx, const Bin1D &biny) const =0

Returns true if area defined by two bins is inside or on border of polygon (more precisely, if mid point of two bins satisfy this condition). 
";


// File: classLine.xml
%feature("docstring") Line "

A line segment, for use in detector masks.

C++ includes: Line.h
";

%feature("docstring")  Line::Line "Line::Line(double x1, double y1, double x2, double y2)
";

%feature("docstring")  Line::clone "Line* Line::clone() const override
";

%feature("docstring")  Line::contains "bool Line::contains(double x, double y) const override

Returns true if point with given coordinates is inside or on border of the shape. 
";

%feature("docstring")  Line::contains "bool Line::contains(const Bin1D &binx, const Bin1D &biny) const override

Returns true if area defined by two bins is inside or on border of polygon (more precisely, if mid point of two bins satisfy this condition). 
";


// File: classLLData.xml
%feature("docstring") LLData "

Template class to store data of any type in multi-dimensional space (low-level).

C++ includes: LLData.h
";

%feature("docstring")  LLData::LLData "LLData< T >::LLData(size_t rank, const int *sizes)
";

%feature("docstring")  LLData::LLData "LLData< T >::LLData(const LLData< T > &right)
";

%feature("docstring")  LLData::~LLData "LLData< T >::~LLData()
";

%feature("docstring")  LLData::meanValues "LLData<double> LLData< T >::meanValues() const
";

%feature("docstring")  LLData::setAll "void LLData< T >::setAll(const T &value)
";

%feature("docstring")  LLData::getTotalSize "size_t LLData< T >::getTotalSize() const
";

%feature("docstring")  LLData::rank "size_t LLData< T >::rank() const
";

%feature("docstring")  LLData::sizes "const int* LLData< T >::sizes() const
";

%feature("docstring")  LLData::getTotalSum "T LLData< T >::getTotalSum() const
";

%feature("docstring")  LLData::max "T LLData< T >::max() const
";


// File: classMaskPattern.xml
%feature("docstring") MaskPattern "";

%feature("docstring")  MaskPattern::MaskPattern "MaskPattern::MaskPattern(IShape2D *shape_, bool doMask_)
";

%feature("docstring")  MaskPattern::MaskPattern "MaskPattern::MaskPattern(const MaskPattern &)=delete
";

%feature("docstring")  MaskPattern::~MaskPattern "MaskPattern::~MaskPattern()
";

%feature("docstring")  MaskPattern::clone "MaskPattern * MaskPattern::clone() const
";


// File: classOffspecCoordinates.xml
%feature("docstring") OffspecCoordinates "

ICoordSystem class that handles the unit translations for off-specular simulations with a spherical detector Its default units are radians for both axes

C++ includes: CoordSystem2D.h
";

%feature("docstring")  OffspecCoordinates::OffspecCoordinates "OffspecCoordinates::OffspecCoordinates(const OwningVector< IAxis > &axes, const Direction &direction)
";

%feature("docstring")  OffspecCoordinates::clone "OffspecCoordinates * OffspecCoordinates::clone() const override
";

%feature("docstring")  OffspecCoordinates::defaultUnits "Coords OffspecCoordinates::defaultUnits() const override
";


// File: classPolFilter.xml
%feature("docstring") PolFilter "

Detector properties (efficiency, transmission).

C++ includes: PolFilter.h
";

%feature("docstring")  PolFilter::PolFilter "PolFilter::PolFilter(R3 direction, double efficiency, double total_transmission)
";

%feature("docstring")  PolFilter::PolFilter "PolFilter::PolFilter()
";

%feature("docstring")  PolFilter::~PolFilter "PolFilter::~PolFilter() override=default
";

%feature("docstring")  PolFilter::className "std::string PolFilter::className() const final
";

%feature("docstring")  PolFilter::parDefs "std::vector<ParaMeta> PolFilter::parDefs() const final
";

%feature("docstring")  PolFilter::matrix "SpinMatrix PolFilter::matrix() const

Return the polarization density matrix (in spin basis along z-axis) 
";

%feature("docstring")  PolFilter::analyzerDirection "R3 PolFilter::analyzerDirection() const

Retrieve the analyzer characteristics. 
";

%feature("docstring")  PolFilter::analyzerEfficiency "double PolFilter::analyzerEfficiency() const

will always return positive value 
";

%feature("docstring")  PolFilter::totalTransmission "double PolFilter::totalTransmission() const
";


// File: classPolygon.xml
%feature("docstring") Polygon "

A polygon, for use in detector masks.  Polygon defined by two arrays with x and y coordinates of points. Sizes of arrays should coincide. If polygon is unclosed (the last point doesn't repeat the first one), it will be closed automatically.

C++ includes: Polygon.h
";

%feature("docstring")  Polygon::Polygon "Polygon::Polygon(std::vector< double > x, std::vector< double > y)

Parameters:
-----------

x: 
Vector of x-coordinates of polygon points.

y: 
Vector of y-coordinates of polygon points. If polygon is unclosed (the last point doesn't repeat the first one), it will be closed automatically. 
";

%feature("docstring")  Polygon::Polygon "Polygon::Polygon(std::vector< std::pair< double, double >> points)

If polygon is unclosed (the last point doesn't repeat the first one), it will be closed automatically.

Parameters:
-----------

points: 
Two dimensional vector of (x,y) coordinates of polygon points. 
";

%feature("docstring")  Polygon::Polygon "Polygon::Polygon(const PolygonPrivate *d)
";

%feature("docstring")  Polygon::~Polygon "Polygon::~Polygon() override
";

%feature("docstring")  Polygon::clone "Polygon* Polygon::clone() const override
";

%feature("docstring")  Polygon::contains "bool Polygon::contains(double x, double y) const override

Returns true if point with given coordinates is inside or on border of the shape. 
";

%feature("docstring")  Polygon::contains "bool Polygon::contains(const Bin1D &binx, const Bin1D &biny) const override

Returns true if area defined by two bins is inside or on border of polygon (more precisely, if mid point of two bins satisfy this condition). 
";

%feature("docstring")  Polygon::getArea "double Polygon::getArea() const
";

%feature("docstring")  Polygon::getPoints "void Polygon::getPoints(std::vector< double > &xpos, std::vector< double > &ypos) const
";


// File: classPolygonPrivate.xml
%feature("docstring") PolygonPrivate "

The private data for polygons to hide boost dependency from the header. 
";

%feature("docstring")  PolygonPrivate::PolygonPrivate "PolygonPrivate::PolygonPrivate(const std::vector< double > &x, const std::vector< double > &y)
";

%feature("docstring")  PolygonPrivate::PolygonPrivate "PolygonPrivate::PolygonPrivate(const std::vector< std::pair< double, double >> &pts)
";

%feature("docstring")  PolygonPrivate::get_points "void PolygonPrivate::get_points(std::vector< double > &xpos, std::vector< double > &ypos)
";


// File: classPowerfield.xml
%feature("docstring") Powerfield "

Templated class to store data in multi-dimensional space. Used with type T = double,  CumulativeValue, bool

C++ includes: Powerfield.h
";

%feature("docstring")  Powerfield::Powerfield "Powerfield< T >::Powerfield(const IAxis &xAxis)
";

%feature("docstring")  Powerfield::Powerfield "Powerfield< T >::Powerfield(const IAxis &xAxis, const IAxis &yAxis)
";

%feature("docstring")  Powerfield::Powerfield "Powerfield< T >::Powerfield(const std::vector< IAxis * > &axes)

Constructor that takes ownership of supplied axes. 
";

%feature("docstring")  Powerfield::Powerfield "Powerfield< T >::Powerfield(const Powerfield &)=delete
";

%feature("docstring")  Powerfield::Powerfield "Powerfield< T >::Powerfield(Powerfield &&)
";

%feature("docstring")  Powerfield::~Powerfield "Powerfield< T >::~Powerfield() override
";

%feature("docstring")  Powerfield::clone "Powerfield< T > * Powerfield< T >::clone() const
";

%feature("docstring")  Powerfield::copyFrom "void Powerfield< T >::copyFrom(const Powerfield< T > &other)
";

%feature("docstring")  Powerfield::meanValues "Powerfield< double > * Powerfield< T >::meanValues() const
";

%feature("docstring")  Powerfield::allocatedSize "size_t Powerfield< T >::allocatedSize() const

Returns total size of data buffer (product of bin number in every dimension). 
";

%feature("docstring")  Powerfield::getRawDataVector "std::vector< T > Powerfield< T >::getRawDataVector() const

Returns copy of raw data vector. 
";

%feature("docstring")  Powerfield::totalSum "T Powerfield< T >::totalSum() const

Returns sum of all values in the data structure. 
";

%feature("docstring")  Powerfield::begin "Powerfield< T >::iterator Powerfield< T >::begin()

Returns read/write iterator that points to the first element. 
";

%feature("docstring")  Powerfield::cbegin "Powerfield< T >::const_iterator Powerfield< T >::cbegin() const

Returns read-only iterator that points to the first element. 
";

%feature("docstring")  Powerfield::end "iterator Powerfield< T >::end()

Returns read/write iterator that points to the one past last element. 
";

%feature("docstring")  Powerfield::cend "const_iterator Powerfield< T >::cend() const

Returns read-only iterator that points to the one past last element. 
";

%feature("docstring")  Powerfield::clear "void Powerfield< T >::clear()

Sets object into initial state (no dimensions, data) 
";

%feature("docstring")  Powerfield::setAllTo "void Powerfield< T >::setAllTo(const T &value)

Sets content of output data to specific value. 
";

%feature("docstring")  Powerfield::setRawDataVector "void Powerfield< T >::setRawDataVector(const std::vector< T > &data_vector)

Sets new values to raw data vector. 
";

%feature("docstring")  Powerfield::setRawDataArray "void Powerfield< T >::setRawDataArray(const T *source)

Sets new values to raw data array. 
";

%feature("docstring")  Powerfield::getValue "double Powerfield< T >::getValue(size_t index) const

Returns value or summed value, depending on T. 
";

%feature("docstring")  Powerfield::hasSameSizes "bool Powerfield< T >::hasSameSizes(const Powerfield< U > &other) const

Returns true if object have same dimensions and number of axes bins.

Returns true if object have same dimensions. 
";

%feature("docstring")  Powerfield::hasSameShape "bool Powerfield< T >::hasSameShape(const Powerfield< U > &other) const

Returns true if objects a) have same dimensions b) bin boundaries of axes coincide.

Returns true if object have same dimensions and shape of axis. 
";

%feature("docstring")  Powerfield::getArray "PyObject* Powerfield< T >::getArray() const

Returns data as Python numpy array. 
";

%feature("docstring")  Powerfield::isInitialized "bool Powerfield< T >::isInitialized() const

Returns true if object is correctly initialized. 
";

%feature("docstring")  Powerfield::allocate "void Powerfield< T >::allocate()

Allocates memory for current dimensions configuration. 
";

%feature("docstring")  Powerfield::normalizedToMaximum "const Powerfield<double>& Powerfield< T >::normalizedToMaximum()
";

%feature("docstring")  Powerfield::getArray "PyObject * Powerfield< double >::getArray() const
";

%feature("docstring")  Powerfield::getValue "double Powerfield< double >::getValue(size_t index) const
";

%feature("docstring")  Powerfield::getValue "double Powerfield< CumulativeValue >::getValue(size_t index) const
";

%feature("docstring")  Powerfield::normalizedToMaximum "const Powerfield< double > & Powerfield< double >::normalizedToMaximum()
";

%feature("docstring")  Powerfield::getArray "PyObject * Powerfield< double >::getArray() const

Returns data as Python numpy array. 
";


// File: classPowerfieldIterator.xml
%feature("docstring") PowerfieldIterator "

Iterator for underlying  Powerfield container.

C++ includes: PowerfieldIterator.h
";

%feature("docstring")  PowerfieldIterator::PowerfieldIterator "PowerfieldIterator< TValue, TContainer >::PowerfieldIterator()

Empty constructor to comply with stl forward iterators. 
";

%feature("docstring")  PowerfieldIterator::PowerfieldIterator "PowerfieldIterator< TValue, TContainer >::PowerfieldIterator(TContainer *p_output_data, size_t start_at_index=0)

constructor 
";

%feature("docstring")  PowerfieldIterator::PowerfieldIterator "PowerfieldIterator< TValue, TContainer >::PowerfieldIterator(const PowerfieldIterator< TValue2, TContainer2 > &other)

templated copy construction 
";

%feature("docstring")  PowerfieldIterator::PowerfieldIterator "PowerfieldIterator< TValue, TContainer >::PowerfieldIterator(const PowerfieldIterator< TValue, TContainer > &other)

non-templated copy construction 
";

%feature("docstring")  PowerfieldIterator::~PowerfieldIterator "PowerfieldIterator< TValue, TContainer >::~PowerfieldIterator()
";

%feature("docstring")  PowerfieldIterator::getIndex "size_t PowerfieldIterator< TValue, TContainer >::getIndex() const

Returns current index. 
";

%feature("docstring")  PowerfieldIterator::getContainer "TContainer* PowerfieldIterator< TValue, TContainer >::getContainer() const

Returns container pointer. 
";

%feature("docstring")  PowerfieldIterator::swap "void PowerfieldIterator< TValue, TContainer >::swap(PowerfieldIterator< TValue, TContainer > &other)

Swaps iterators. 
";


// File: classReadReflectometry.xml
%feature("docstring") ReadReflectometry "

Class for reading reflectometry data from ASCII file.

C++ includes: ReadReflectometry.h
";

%feature("docstring")  ReadReflectometry::readPowerfield "Powerfield< double > * ReadReflectometry::readPowerfield(std::istream &inStream)
";


// File: classReadWriteINT.xml
%feature("docstring") ReadWriteINT "

Class for reading and writing BornAgain native IntensityData from ASCII file.

C++ includes: ReadWriteINT.h
";

%feature("docstring")  ReadWriteINT::readPowerfield "Powerfield< double > * ReadWriteINT::readPowerfield(std::istream &input_stream)
";

%feature("docstring")  ReadWriteINT::writePowerfield "void ReadWriteINT::writePowerfield(const Powerfield< double > &data, std::ostream &output_stream)
";


// File: classReadWriteNumpyTXT.xml
%feature("docstring") ReadWriteNumpyTXT "

Class for reading and writing  Powerfield from simple ASCII file with the layout as in numpy.savetxt.

C++ includes: ReadWriteNumpyTXT.h
";

%feature("docstring")  ReadWriteNumpyTXT::readPowerfield "Powerfield< double > * ReadWriteNumpyTXT::readPowerfield(std::istream &input_stream)
";

%feature("docstring")  ReadWriteNumpyTXT::writePowerfield "void ReadWriteNumpyTXT::writePowerfield(const Powerfield< double > &data, std::ostream &output_stream)
";


// File: classRectangle.xml
%feature("docstring") Rectangle "

A rectangle, for use in detector masks.

Edges are along the coordinate axes.

C++ includes: Rectangle.h
";

%feature("docstring")  Rectangle::Rectangle "Rectangle::Rectangle(double xlow, double ylow, double xup, double yup, bool inverted=false)

Parameters:
-----------

xlow: 
x-coordinate of lower left corner

ylow: 
y-coordinate of lower left corner

xup: 
x-coordinate of upper right corner

yup: 
y-coordinate of upper right corner

inverted: 
swap inside/outside 
";

%feature("docstring")  Rectangle::clone "Rectangle* Rectangle::clone() const override
";

%feature("docstring")  Rectangle::setInverted "void Rectangle::setInverted(bool inverted=true)
";

%feature("docstring")  Rectangle::contains "bool Rectangle::contains(double x, double y) const override

Returns true if point with given coordinates is inside or on border of the shape. 
";

%feature("docstring")  Rectangle::contains "bool Rectangle::contains(const Bin1D &binx, const Bin1D &biny) const override

Returns true if area defined by two bins is inside or on border of polygon (more precisely, if mid point of two bins satisfy this condition). 
";

%feature("docstring")  Rectangle::getArea "double Rectangle::getArea() const
";

%feature("docstring")  Rectangle::getXlow "double Rectangle::getXlow() const
";

%feature("docstring")  Rectangle::getYlow "double Rectangle::getYlow() const
";

%feature("docstring")  Rectangle::getXup "double Rectangle::getXup() const
";

%feature("docstring")  Rectangle::getYup "double Rectangle::getYup() const
";


// File: classRectangularDetector.xml
%feature("docstring") RectangularDetector "

A flat rectangular detector with axes and resolution function.

C++ includes: RectangularDetector.h
";

%feature("docstring")  RectangularDetector::RectangularDetector "RectangularDetector::RectangularDetector(size_t nxbins, double width, size_t nybins, double height)

Rectangular detector constructor

Parameters:
-----------

nxbins: 
Number of bins (pixels) in x-direction

width: 
Width of the detector in mm along x-direction

nybins: 
Number of bins (pixels) in y-direction

height: 
Height of the detector in mm along y-direction 
";

%feature("docstring")  RectangularDetector::RectangularDetector "RectangularDetector::RectangularDetector(const RectangularDetector &other)
";

%feature("docstring")  RectangularDetector::~RectangularDetector "RectangularDetector::~RectangularDetector() override
";

%feature("docstring")  RectangularDetector::clone "RectangularDetector * RectangularDetector::clone() const override
";

%feature("docstring")  RectangularDetector::className "std::string RectangularDetector::className() const final
";

%feature("docstring")  RectangularDetector::setDetectorNormal "void RectangularDetector::setDetectorNormal(const Direction &direction) override

Inits detector with the beam settings. 
";

%feature("docstring")  RectangularDetector::setDetectorPosition "void RectangularDetector::setDetectorPosition(R3 normal_to_detector, double u0, double v0, R3 direction=R3(0.0, -1.0, 0.0))
";

%feature("docstring")  RectangularDetector::setPerpendicularToSampleX "void RectangularDetector::setPerpendicularToSampleX(double distance, double u0, double v0)
";

%feature("docstring")  RectangularDetector::setPerpendicularToDirectBeam "void RectangularDetector::setPerpendicularToDirectBeam(double distance, double u0, double v0)
";

%feature("docstring")  RectangularDetector::setPerpendicularToReflectedBeam "void RectangularDetector::setPerpendicularToReflectedBeam(double distance, double u0=0.0, double v0=0.0)
";

%feature("docstring")  RectangularDetector::setDirectBeamPosition "void RectangularDetector::setDirectBeamPosition(double u0, double v0)
";

%feature("docstring")  RectangularDetector::width "double RectangularDetector::width() const
";

%feature("docstring")  RectangularDetector::height "double RectangularDetector::height() const
";

%feature("docstring")  RectangularDetector::getNbinsX "size_t RectangularDetector::getNbinsX() const
";

%feature("docstring")  RectangularDetector::getNbinsY "size_t RectangularDetector::getNbinsY() const
";

%feature("docstring")  RectangularDetector::getNormalVector "R3 RectangularDetector::getNormalVector() const
";

%feature("docstring")  RectangularDetector::getU0 "double RectangularDetector::getU0() const
";

%feature("docstring")  RectangularDetector::getV0 "double RectangularDetector::getV0() const
";

%feature("docstring")  RectangularDetector::getDirectionVector "R3 RectangularDetector::getDirectionVector() const
";

%feature("docstring")  RectangularDetector::getDistance "double RectangularDetector::getDistance() const
";

%feature("docstring")  RectangularDetector::getDirectBeamU0 "double RectangularDetector::getDirectBeamU0() const
";

%feature("docstring")  RectangularDetector::getDirectBeamV0 "double RectangularDetector::getDirectBeamV0() const
";

%feature("docstring")  RectangularDetector::getDetectorArrangment "RectangularDetector::EDetectorArrangement RectangularDetector::getDetectorArrangment() const
";

%feature("docstring")  RectangularDetector::defaultCoords "Coords RectangularDetector::defaultCoords() const override

Returns default axes units. 
";

%feature("docstring")  RectangularDetector::regionOfInterestPixel "RectangularPixel * RectangularDetector::regionOfInterestPixel() const
";

%feature("docstring")  RectangularDetector::offspecCoords "ICoordSystem * RectangularDetector::offspecCoords(IAxis *beamAxis, const Direction &beamDirection) const override
";

%feature("docstring")  RectangularDetector::scatteringCoords "CoordSystem2D * RectangularDetector::scatteringCoords(const Beam &beam) const override
";


// File: classResolutionFunction2DGaussian.xml
%feature("docstring") ResolutionFunction2DGaussian "

Simple gaussian two-dimensional resolution function.

C++ includes: ResolutionFunction2DGaussian.h
";

%feature("docstring")  ResolutionFunction2DGaussian::ResolutionFunction2DGaussian "ResolutionFunction2DGaussian::ResolutionFunction2DGaussian(double sigma_x, double sigma_y)
";

%feature("docstring")  ResolutionFunction2DGaussian::clone "ResolutionFunction2DGaussian* ResolutionFunction2DGaussian::clone() const override
";

%feature("docstring")  ResolutionFunction2DGaussian::className "std::string ResolutionFunction2DGaussian::className() const final
";

%feature("docstring")  ResolutionFunction2DGaussian::parDefs "std::vector<ParaMeta> ResolutionFunction2DGaussian::parDefs() const final
";

%feature("docstring")  ResolutionFunction2DGaussian::evaluateCDF "double ResolutionFunction2DGaussian::evaluateCDF(double x, double y) const override
";

%feature("docstring")  ResolutionFunction2DGaussian::sigmaX "double ResolutionFunction2DGaussian::sigmaX() const
";

%feature("docstring")  ResolutionFunction2DGaussian::sigmaY "double ResolutionFunction2DGaussian::sigmaY() const
";


// File: structIDetector_1_1RoiOfAxis.xml


// File: classSimulationAreaIterator.xml
%feature("docstring") SimulationAreaIterator "

An iterator for SimulationArea.

C++ includes: SimulationAreaIterator.h
";

%feature("docstring")  SimulationAreaIterator::createEnd "SimulationAreaIterator SimulationAreaIterator::createEnd() const

Convenience function to create an end-iterator matching to this iterator. 
";

%feature("docstring")  SimulationAreaIterator::roiIndex "size_t SimulationAreaIterator::roiIndex() const
";

%feature("docstring")  SimulationAreaIterator::detectorIndex "size_t SimulationAreaIterator::detectorIndex() const
";


// File: classSimulationResult.xml
%feature("docstring") SimulationResult "

Wrapper around Powerfield<double> that also provides unit conversions.

C++ includes: SimulationResult.h
";

%feature("docstring")  SimulationResult::SimulationResult "SimulationResult::SimulationResult()=default
";

%feature("docstring")  SimulationResult::SimulationResult "SimulationResult::SimulationResult(const Powerfield< double > &data, const ICoordSystem &coords)
";

%feature("docstring")  SimulationResult::SimulationResult "SimulationResult::SimulationResult(const Powerfield< double > &data, const ICoordSystem *&&coords)
";

%feature("docstring")  SimulationResult::~SimulationResult "SimulationResult::~SimulationResult()
";

%feature("docstring")  SimulationResult::SimulationResult "SimulationResult::SimulationResult(const SimulationResult &other)
";

%feature("docstring")  SimulationResult::SimulationResult "SimulationResult::SimulationResult(SimulationResult &&other)
";

%feature("docstring")  SimulationResult::data "std::unique_ptr< Powerfield< double > > SimulationResult::data(Coords units=Coords::UNDEFINED) const
";

%feature("docstring")  SimulationResult::histogram2d "Histogram2D * SimulationResult::histogram2d(Coords units=Coords::UNDEFINED) const
";

%feature("docstring")  SimulationResult::axisInfo "std::vector< AxisInfo > SimulationResult::axisInfo(Coords units=Coords::UNDEFINED) const

Provide  AxisInfo for each axis and the given units. 
";

%feature("docstring")  SimulationResult::converter "const ICoordSystem & SimulationResult::converter() const

Returns underlying unit converter. 
";

%feature("docstring")  SimulationResult::size "size_t SimulationResult::size() const
";

%feature("docstring")  SimulationResult::empty "bool SimulationResult::empty() const
";

%feature("docstring")  SimulationResult::relativeToMaximum "SimulationResult SimulationResult::relativeToMaximum() const

Returns modified  SimulationResult: all intensities dvided by maximum intensity. 
";

%feature("docstring")  SimulationResult::array "PyObject * SimulationResult::array(Coords units=Coords::UNDEFINED) const

Returns intensity data as Python numpy array. 
";

%feature("docstring")  SimulationResult::convertedBinCenters "std::vector< double > SimulationResult::convertedBinCenters(Coords units=Coords::UNDEFINED) const
";

%feature("docstring")  SimulationResult::convertedBinCenters "std::vector< double > SimulationResult::convertedBinCenters(size_t i_axis, Coords units=Coords::UNDEFINED) const

Returns axis coordinates as a numpy array. With no parameters given Returns coordinates of x-axis in default units. 
";

%feature("docstring")  SimulationResult::setTitle "void SimulationResult::setTitle(const std::string &title)
";

%feature("docstring")  SimulationResult::title "std::string SimulationResult::title()
";


// File: classSphericalCoords.xml
%feature("docstring") SphericalCoords "

ICoordSystem class that handles the unit translations for spherical detectors Its default units are radians for both axes

C++ includes: CoordSystem2D.h
";

%feature("docstring")  SphericalCoords::SphericalCoords "SphericalCoords::SphericalCoords(const OwningVector< IAxis > &axes, const Direction &direction, double wavelength)
";

%feature("docstring")  SphericalCoords::~SphericalCoords "SphericalCoords::~SphericalCoords() override
";

%feature("docstring")  SphericalCoords::clone "SphericalCoords * SphericalCoords::clone() const override
";

%feature("docstring")  SphericalCoords::availableUnits "std::vector< Coords > SphericalCoords::availableUnits() const override

Returns list of units that are available for all 2D detectors. Further units may be added by child classes. 
";

%feature("docstring")  SphericalCoords::defaultUnits "Coords SphericalCoords::defaultUnits() const override
";


// File: classSphericalDetector.xml
%feature("docstring") SphericalDetector "

A detector with coordinate axes along angles phi and alpha.

C++ includes: SphericalDetector.h
";

%feature("docstring")  SphericalDetector::SphericalDetector "SphericalDetector::SphericalDetector()=default
";

%feature("docstring")  SphericalDetector::SphericalDetector "SphericalDetector::SphericalDetector(size_t n_phi, double phi_min, double phi_max, size_t n_alpha, double alpha_min, double alpha_max)

Returns a detector with given phi and alpha axes.

Parameters:
-----------

n_phi: 
number of phi-axis bins

phi_min: 
low edge of first phi-bin

phi_max: 
upper edge of last phi-bin

n_alpha: 
number of alpha-axis bins

alpha_min: 
low edge of first alpha-bin

alpha_max: 
upper edge of last alpha-bin 
";

%feature("docstring")  SphericalDetector::SphericalDetector "SphericalDetector::SphericalDetector(size_t n_bin, double width, double phi, double alpha)

Returns a detector with phi and alpha axes that have equal width and binning.

Parameters:
-----------

n_bin: 
number of bins per direction

width: 
full width of angular range in phi or alpha

phi: 
central phi angle

alpha: 
central alpha angle 
";

%feature("docstring")  SphericalDetector::SphericalDetector "SphericalDetector::SphericalDetector(const SphericalDetector &other)
";

%feature("docstring")  SphericalDetector::~SphericalDetector "SphericalDetector::~SphericalDetector() override=default
";

%feature("docstring")  SphericalDetector::clone "SphericalDetector * SphericalDetector::clone() const override
";

%feature("docstring")  SphericalDetector::className "std::string SphericalDetector::className() const override
";

%feature("docstring")  SphericalDetector::defaultCoords "Coords SphericalDetector::defaultCoords() const override

Returns default axes units. 
";

%feature("docstring")  SphericalDetector::offspecCoords "ICoordSystem * SphericalDetector::offspecCoords(IAxis *beamAxis, const Direction &beamDirection) const override
";

%feature("docstring")  SphericalDetector::scatteringCoords "CoordSystem2D * SphericalDetector::scatteringCoords(const Beam &beam) const override
";


// File: classVerticalLine.xml
%feature("docstring") VerticalLine "

An infinite vertical line.

C++ includes: Line.h
";

%feature("docstring")  VerticalLine::VerticalLine "VerticalLine::VerticalLine(double x)

Parameters:
-----------

x: 
The value at which it crosses x-axes 
";

%feature("docstring")  VerticalLine::clone "VerticalLine* VerticalLine::clone() const override
";

%feature("docstring")  VerticalLine::contains "bool VerticalLine::contains(double x, double y) const override

Returns true if point with given coordinates is inside or on border of the shape. 
";

%feature("docstring")  VerticalLine::contains "bool VerticalLine::contains(const Bin1D &binx, const Bin1D &biny) const override

Returns true if area defined by two bins is inside or on border of polygon (more precisely, if mid point of two bins satisfy this condition). 
";

%feature("docstring")  VerticalLine::getXpos "double VerticalLine::getXpos() const
";


// File: classWavenumberReflectometryCoordinates.xml
%feature("docstring") WavenumberReflectometryCoordinates "

Conversion of axis units for the case of q-defined reflectometry.

C++ includes: CoordSystem1D.h
";

%feature("docstring")  WavenumberReflectometryCoordinates::WavenumberReflectometryCoordinates "WavenumberReflectometryCoordinates::WavenumberReflectometryCoordinates(const IAxis *&&axis)
";

%feature("docstring")  WavenumberReflectometryCoordinates::~WavenumberReflectometryCoordinates "WavenumberReflectometryCoordinates::~WavenumberReflectometryCoordinates() override
";

%feature("docstring")  WavenumberReflectometryCoordinates::clone "WavenumberReflectometryCoordinates * WavenumberReflectometryCoordinates::clone() const override
";

%feature("docstring")  WavenumberReflectometryCoordinates::availableUnits "std::vector< Coords > WavenumberReflectometryCoordinates::availableUnits() const override

Returns the list of all available units. 
";

%feature("docstring")  WavenumberReflectometryCoordinates::defaultUnits "Coords WavenumberReflectometryCoordinates::defaultUnits() const override

Returns default units to convert to. 
";


// File: classConvolve_1_1Workspace.xml


// File: namespace_0d0.xml


// File: namespace_0d10.xml


// File: namespace_0d12.xml


// File: namespace_0d21.xml


// File: namespace_0d29.xml


// File: namespace_0d50.xml


// File: namespace_0d56.xml


// File: namespace_0d58.xml


// File: namespaceDataUtils.xml


// File: namespaceDataUtils_1_1Array.xml
%feature("docstring")  DataUtils::Array::getShape "std::pair< size_t, size_t > DataUtils::Array::getShape(const std::vector< std::vector< double >> &data)

Returns shape nrows, ncols of 2D array. 
";

%feature("docstring")  DataUtils::Array::createData "std::unique_ptr< Powerfield< double > > DataUtils::Array::createData(const std::vector< double > &vec)
";

%feature("docstring")  DataUtils::Array::createData "std::unique_ptr< Powerfield< double > > DataUtils::Array::createData(const std::vector< std::vector< double >> &vec)
";

%feature("docstring")  DataUtils::Array::createVector1D "std::vector< double > DataUtils::Array::createVector1D(const Powerfield< double > &data)

Creates 1D vector from  Powerfield. 
";

%feature("docstring")  DataUtils::Array::createVector2D "std::vector< std::vector< double > > DataUtils::Array::createVector2D(const Powerfield< double > &data)

Creates 2D vector from  Powerfield. 
";


// File: namespaceDataUtils_1_1AxisNames.xml


// File: namespaceDataUtils_1_1Data.xml
%feature("docstring")  DataUtils::Data::relativeDataDifference "double DataUtils::Data::relativeDataDifference(const Powerfield< double > &dat, const Powerfield< double > &ref)

Returns relative difference between two data sets sum(dat[i] - ref[i])/ref[i]). 
";

%feature("docstring")  DataUtils::Data::coordinateToBinf "double DataUtils::Data::coordinateToBinf(double coordinate, const IAxis &axis)

Transforms coordinate on axis into the bin-fraction-coordinate. 
";

%feature("docstring")  DataUtils::Data::coordinateFromBinf "double DataUtils::Data::coordinateFromBinf(double value, const IAxis &axis)

Transforms bin-fraction-coordinate into axis coordinate. 
";

%feature("docstring")  DataUtils::Data::coordinateToBinf "void DataUtils::Data::coordinateToBinf(double &x, double &y, const Powerfield< double > &data)

Transforms x,y coordinate from  Powerfield axes coordinates to bin-fraction-coordinates. 
";

%feature("docstring")  DataUtils::Data::coordinateFromBinf "void DataUtils::Data::coordinateFromBinf(double &x, double &y, const Powerfield< double > &data)

Transforms x,y coordinate from bin-fraction-coordinates to  Powerfield's axes coordinates. 
";

%feature("docstring")  DataUtils::Data::create2DArrayfromPowerfield "std::vector< std::vector< double > > DataUtils::Data::create2DArrayfromPowerfield(const Powerfield< double > &data)

Creates a vector of vectors of double (2D  Array) from  Powerfield. 
";

%feature("docstring")  DataUtils::Data::importArrayToPowerfield "Powerfield< double > * DataUtils::Data::importArrayToPowerfield(const std::vector< double > &vec)

Reads 1D array of doubles to Python, for use in persistence test. 
";

%feature("docstring")  DataUtils::Data::importArrayToPowerfield "Powerfield< double > * DataUtils::Data::importArrayToPowerfield(const std::vector< std::vector< double >> &vec)

Reads 2D array of doubles to Python, for use in persistence test. 
";

%feature("docstring")  DataUtils::Data::createRelativeDifferenceData "std::unique_ptr< Powerfield< double > > DataUtils::Data::createRelativeDifferenceData(const Powerfield< double > &data, const Powerfield< double > &reference)
";

%feature("docstring")  DataUtils::Data::createRearrangedDataSet "std::unique_ptr< Powerfield< double > > DataUtils::Data::createRearrangedDataSet(const Powerfield< double > &data, int n)

Returns new object with input data rotated by n*90 deg counterclockwise (n > 0) or clockwise (n < 0) Axes are swapped if the data is effectively rotated by 90 or 270 degrees Applicable to 2D arrays only 
";

%feature("docstring")  DataUtils::Data::createClippedDataSet "std::unique_ptr< Powerfield< double > > DataUtils::Data::createClippedDataSet(const Powerfield< double > &origin, double x1, double y1, double x2, double y2)

Returns new IntensityData objects which axes clipped to represent the specified rectangle. 
";

%feature("docstring")  DataUtils::Data::createPowerfieldfrom2DArray "std::unique_ptr< Powerfield< double > > DataUtils::Data::createPowerfieldfrom2DArray(const std::vector< std::vector< double >> &array_2d)

Creates  Powerfield from a 2D  Array. 
";

%feature("docstring")  DataUtils::Data::createFFT "std::unique_ptr< Powerfield< double > > DataUtils::Data::createFFT(const Powerfield< double > &data)

Creates Fourier Transform ( Powerfield format) of intensity map ( Powerfield format). 
";


// File: namespaceDataUtils_1_1Format.xml
%feature("docstring")  DataUtils::Format::isCompressed "bool DataUtils::Format::isCompressed(const std::string &name)

Returns true if name contains *.gz extension. 
";

%feature("docstring")  DataUtils::Format::isGZipped "bool DataUtils::Format::isGZipped(const std::string &name)

Returns true if name contains *.gz extension.

Does name contain *.gz extension? 
";

%feature("docstring")  DataUtils::Format::isBZipped "bool DataUtils::Format::isBZipped(const std::string &name)

Returns true if name contains *.bz2 extension. 
";

%feature("docstring")  DataUtils::Format::isIntFile "bool DataUtils::Format::isIntFile(const std::string &file_name)

Returns true if file name corresponds to BornAgain native format (compressed or not) 
";

%feature("docstring")  DataUtils::Format::isNicosFile "bool DataUtils::Format::isNicosFile(const std::string &file_name)

Returns true if file name corresponds to Nicos format (compressed or not) 
";

%feature("docstring")  DataUtils::Format::isTiffFile "bool DataUtils::Format::isTiffFile(const std::string &file_name)

Returns true if file name corresponds to tiff file (can be also compressed) 
";

%feature("docstring")  DataUtils::Format::createAxis "IAxis * DataUtils::Format::createAxis(std::istream &input_stream)

Creates axis of certain type from input stream. 
";

%feature("docstring")  DataUtils::Format::fillPowerfield "void DataUtils::Format::fillPowerfield(Powerfield< double > *data, std::istream &input_stream)

Fills output data raw buffer from input stream. 
";

%feature("docstring")  DataUtils::Format::parse_doubles "std::vector< double > DataUtils::Format::parse_doubles(const std::string &str)

Parse double values from string to vector of double. 
";

%feature("docstring")  DataUtils::Format::readLineOfDoubles "void DataUtils::Format::readLineOfDoubles(std::vector< double > &buffer, std::istringstream &iss)
";


// File: namespaceDataUtils_1_1Histo.xml
%feature("docstring")  DataUtils::Histo::FindPeaks "std::vector< std::pair< double, double > > DataUtils::Histo::FindPeaks(const Histogram2D &hist, double sigma=2, const std::string &option={}, double threshold=0.05)

Returns vector of peak center coordinates, for peaks in given histogram. 
";

%feature("docstring")  DataUtils::Histo::RelativeDifference "double DataUtils::Histo::RelativeDifference(const SimulationResult &dat, const SimulationResult &ref)

Returns sum of relative differences between each pair of elements: (a, b) -> 2*abs(a - b)/(a + b) ( and zero if a-b=0 )

Returns sum of relative differences between each pair of elements: (a, b) -> 2*abs(a - b)/(|a| + |b|) ( and zero if a=b=0 within epsilon ) 
";

%feature("docstring")  DataUtils::Histo::getRelativeDifference "double DataUtils::Histo::getRelativeDifference(const IHistogram &dat, const IHistogram &ref)
";

%feature("docstring")  DataUtils::Histo::checkRelativeDifference "bool DataUtils::Histo::checkRelativeDifference(const Powerfield< double > &dat, const Powerfield< double > &ref, double threshold)

Returns true is relative difference is below threshold; prints informative output. 
";

%feature("docstring")  DataUtils::Histo::agreesWithReference "bool DataUtils::Histo::agreesWithReference(const SimulationResult &dat, const std::string &refFileName, double tol)

Returns true if SimulatioResult agrees with data from reference file. 
";

%feature("docstring")  DataUtils::Histo::filesAgree "bool DataUtils::Histo::filesAgree(const std::string &datFileName, const std::string &refFileName, double tol)

Returns true if data in both files agree. 
";


// File: namespaceIO.xml
%feature("docstring")  IO::readNicosData "Powerfield< double > * IO::readNicosData(std::istream &input_stream)
";


// File: Beam_8cpp.xml


// File: Beam_8h.xml


// File: FootprintGauss_8cpp.xml


// File: FootprintGauss_8h.xml


// File: FootprintSquare_8cpp.xml


// File: FootprintSquare_8h.xml


// File: IFootprintFactor_8cpp.xml


// File: IFootprintFactor_8h.xml


// File: AxisNames_8cpp.xml


// File: AxisNames_8h.xml


// File: CoordSystem1D_8cpp.xml


// File: CoordSystem1D_8h.xml


// File: CoordSystem2D_8cpp.xml


// File: CoordSystem2D_8h.xml


// File: ICoordSystem_8cpp.xml


// File: ICoordSystem_8h.xml


// File: Tags_8h.xml


// File: ArrayUtils_8cpp.xml


// File: ArrayUtils_8h.xml


// File: CumulativeValue_8cpp.xml


// File: CumulativeValue_8h.xml


// File: DataUtils_8cpp.xml


// File: DataUtils_8h.xml


// File: LLData_8h.xml
%feature("docstring")  HaveSameSizes "bool HaveSameSizes(const LLData< T > &left, const LLData< T > &right)
";


// File: Powerfield_8cpp.xml


// File: Powerfield_8h.xml


// File: PowerfieldIterator_8h.xml
%feature("docstring")  swap "void swap(PowerfieldIterator< TValue, TContainer > &left, PowerfieldIterator< TValue, TContainer > &right)

make Swappable 
";


// File: DetectorContext_8cpp.xml


// File: DetectorContext_8h.xml


// File: IDetector_8cpp.xml


// File: IDetector_8h.xml


// File: RectangularDetector_8cpp.xml


// File: RectangularDetector_8h.xml


// File: SimulationAreaIterator_8cpp.xml


// File: SimulationAreaIterator_8h.xml


// File: SphericalDetector_8cpp.xml


// File: SphericalDetector_8h.xml


// File: Histogram1D_8cpp.xml


// File: Histogram1D_8h.xml


// File: Histogram2D_8cpp.xml


// File: Histogram2D_8h.xml


// File: HistoUtils_8cpp.xml


// File: HistoUtils_8h.xml


// File: IHistogram_8cpp.xml


// File: IHistogram_8h.xml


// File: IOFactory_8cpp.xml


// File: IOFactory_8h.xml


// File: SimulationResult_8cpp.xml


// File: SimulationResult_8h.xml


// File: boost__streams_8h.xml


// File: DataFormatUtils_8cpp.xml


// File: DataFormatUtils_8h.xml


// File: ReadReflectometry_8cpp.xml


// File: ReadReflectometry_8h.xml


// File: ReadWriteINT_8cpp.xml


// File: ReadWriteINT_8h.xml


// File: ReadWriteNicos_8cpp.xml


// File: ReadWriteNicos_8h.xml


// File: ReadWriteNumpyTXT_8cpp.xml


// File: ReadWriteNumpyTXT_8h.xml


// File: ReadWriteTiff_8cpp.xml


// File: ReadWriteTiff_8h.xml


// File: DetectorMask_8cpp.xml


// File: DetectorMask_8h.xml


// File: Ellipse_8cpp.xml


// File: Ellipse_8h.xml


// File: InfinitePlane_8h.xml


// File: IShape2D_8h.xml


// File: Line_8cpp.xml


// File: Line_8h.xml


// File: Polygon_8cpp.xml


// File: Polygon_8h.xml


// File: Rectangle_8cpp.xml


// File: Rectangle_8h.xml


// File: PolFilter_8cpp.xml


// File: PolFilter_8h.xml


// File: ConvolutionDetectorResolution_8cpp.xml


// File: ConvolutionDetectorResolution_8h.xml


// File: Convolve_8cpp.xml


// File: Convolve_8h.xml


// File: IDetectorResolution_8h.xml


// File: IResolutionFunction2D_8cpp.xml


// File: IResolutionFunction2D_8h.xml


// File: ResolutionFunction2DGaussian_8cpp.xml


// File: ResolutionFunction2DGaussian_8h.xml


// File: dir_045b2146c1496d64c013dbede5cfb743.xml


// File: dir_0bb3c1d1d7b9ebf51620a7778682f6fa.xml


// File: dir_dda0c63858d3307626c38e9d5a1e4058.xml


// File: dir_c3bac8c01fa2e2f8df2b6f9956445782.xml


// File: dir_4c76ddfc10a27668d6c42d3412320ee0.xml


// File: dir_79fd6aafcbcfabf60588d893417cf324.xml


// File: dir_9f013251ba980bff6504d6613b69183d.xml


// File: dir_4866552d576e04b61ad8ade47c8db877.xml


// File: dir_6f4ccf6b1bfd53aaa1440d548704c25a.xml


// File: dir_aa6451b5aab7f40a79bc1a0dc7cac3c6.xml

